.. math::
    \| \frac{1}{N} \sum_i \nabla f_i(\mathbf{\bar{x}}) \|^2

where N is the number of *agents*,
:math:`f_i` is agent i's local cost function,
and :math:`\mathbf{\bar{x}}` is the mean x across all *agents*.
